package cn.wise.sc.cement.business.service.impl;

import cn.hutool.core.util.StrUtil;
import cn.wise.sc.cement.business.entity.Team;
import cn.wise.sc.cement.business.exception.BusinessExceptionEnum;
import cn.wise.sc.cement.business.mapper.TeamMapper;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.model.PageQuery;
import cn.wise.sc.cement.business.model.query.TeamQuery;
import cn.wise.sc.cement.business.model.vo.ClientVo;
import cn.wise.sc.cement.business.model.vo.TeamVo;
import cn.wise.sc.cement.business.service.ITeamService;
import cn.wise.sc.cement.business.util.ExcelUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author ztw
 * @since 2020-08-18
 */
@Service
public class TeamServiceImpl extends ServiceImpl<TeamMapper, Team> implements ITeamService {

	@Resource
	private TeamMapper teamMapper;

	@Override
	public BaseResponse<IPage<TeamVo>> getPage(PageQuery pageQuery, Integer status, Integer gourpId, String name) {
		Map<String, Object> params = new HashMap<>();
		params.put("status", status);
		params.put("gourpId", gourpId);
		params.put("name", name);
		Page<TeamVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
		IPage<TeamVo> pages = teamMapper.getPage(page,params);
		return BaseResponse.okData(pages);
	}


	@Override
	public BaseResponse<List<TeamVo>> getList() {
		QueryWrapper<Team> qw = new QueryWrapper<>();
		qw.eq("status", 1);
		List<Team> list = this.list(qw);
		List<TeamVo> rts = new ArrayList<>(list.size());
		list.forEach(arg -> {
			TeamVo teamVo = new TeamVo();
			teamVo.setId(arg.getId());
			teamVo.setName(arg.getName());
			rts.add(teamVo);
		});
		return BaseResponse.okData(rts);
	}

	@Override
	@Transactional
	public BaseResponse<TeamVo> create(TeamQuery query) {
		Team crate = Team.crate(query);
		this.save(crate);
		return BaseResponse.okData(crate.toVo());
	}

	@Override
	@Transactional
	public BaseResponse<TeamVo> update(TeamQuery query) {
		Team update = Team.crate(query);
		update.setId(query.getId());
		this.updateById(update);
		return BaseResponse.okData(update.toVo());
	}

	@Override
	@Transactional
	public BaseResponse<Boolean> status(Integer status, Integer id) {
		BusinessExceptionEnum.BAD_LICENCE_TYPE.assertNotNull(status);
		BusinessExceptionEnum.BAD_LICENCE_TYPE.assertNotNull(id);
		Team update = new Team();
		update.setId(id);
		update.setStatus(status == 1);
		return BaseResponse.okData(this.updateById(update));
	}

	@Override
	public void export(Integer status, Integer gourpId, String name, String fileName, HttpServletResponse response) {
		Map<String, Object> params = new HashMap<>();
		params.put("status", status);
		params.put("gourpId", gourpId);
		params.put("name", name);
		List<Map<String, Object>> list= teamMapper.exportList(params);

		if (!CollectionUtils.isEmpty(list)) {
			Map<String, Object> map = list.get(0);
			String[] headers = new String[map.size()];
			headers[0] = "序号";
			headers[1] = "检测项目";
			headers[2] = "分组";
			headers[3] = "检测依据";
			headers[4] = "收费标准";
			headers[5] = "建议产值";
			headers[6] = "资质范围";
			List<Object[]> datas = new ArrayList<>(list.size());
			for (Map<String, Object> m : list) {
				Object[] objects = new Object[headers.length];
				for (int j = 0; j < headers.length; j++) {
					String obj = m.get(headers[j]).toString();
					if(j==0){
						obj = obj.split("\\.")[0];
					}
					objects[j] = obj;
				}
				datas.add(objects);
			}
			ExcelUtil.excelExport(
					fileName == null || fileName.trim().length() <= 0 ? "检测项": fileName, headers,
					datas, response);
		}
	}

}
