package cn.wise.sc.cement.business.service.impl;

import cn.wise.sc.cement.business.entity.Project;
import cn.wise.sc.cement.business.entity.SysPermission;
import cn.wise.sc.cement.business.entity.SysUser;
import cn.wise.sc.cement.business.exception.BusinessExceptionEnum;
import cn.wise.sc.cement.business.mapper.SysPermissionMapper;
import cn.wise.sc.cement.business.mapper.SysUserMapper;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.model.LoginUser;
import cn.wise.sc.cement.business.model.PageQuery;
import cn.wise.sc.cement.business.model.query.UserQuery;
import cn.wise.sc.cement.business.model.vo.ClientVo;
import cn.wise.sc.cement.business.model.vo.UserVo;
import cn.wise.sc.cement.business.service.ISysUserService;
import cn.wise.sc.cement.business.util.JwtUtil;
import cn.wise.sc.cement.business.util.RedisUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.formula.functions.BaseNumberUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author ztw
 * @since 2020-08-07
 */
@Service
public class UserServiceImpl extends ServiceImpl<SysUserMapper, SysUser> implements ISysUserService {


	@Resource
	private SysUserMapper userMapper;
	@Resource
	private HttpServletRequest request;
	@Autowired
	RedisUtil redisUtil;
	@Resource
	private SysPermissionMapper permissionMapper;

	/**
	 * 当前登录用户
	 * @return
	 */
	@Override
	public LoginUser getLoginUser() {
		try {
			String token = request.getHeader("Authorization");
			System.out.println("==================Authorization===================");
			System.out.println(token);
			Map map = JwtUtil.parserToken(token);
			Object obj = redisUtil.getString(map.get("id").toString());
			BusinessExceptionEnum.CACHE_NOT_FOUND.assertNotNull(obj);
			SysUser sysUser = userMapper.selectById(Integer.valueOf(map.get("id").toString()));
			LoginUser loginUser = new LoginUser();
			BeanUtils.copyProperties(sysUser, loginUser);
			List<SysPermission> permissionList =  permissionMapper.listByUserId(loginUser.getId());
			loginUser.setPermissions(permissionList);
			return loginUser;
		} catch (Exception e) {
			return null;
		}
	}

	/**
	 * 人员分页列表
	 * @param pageQuery
	 * @param status
	 * @param groupId
	 * @param name
	 * @return
	 */
	@Override
	public BaseResponse<IPage<UserVo>> getPage(PageQuery pageQuery, Integer status, Integer groupId, String name) {
		Map<String, Object> params = new HashMap<>();
		params.put("status", status);
		params.put("groupId", groupId);
		params.put("name", name);
		Page<UserVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
		IPage<UserVo> pages = userMapper.getPage(page,params);
		return BaseResponse.okData(pages);
	}

	/**
	 * 新增人员
	 * @param query
	 * @return
	 */
	@Override
	@Transactional
	public BaseResponse<SysUser> create(UserQuery query) {
		if (StringUtils.isEmpty(query.getPhone())) {
			return BaseResponse.errorMsg("手机号码不可为空!");
		}
		QueryWrapper<SysUser> qw = new QueryWrapper<>();
		qw.eq("phone", query.getPhone());
		int count = userMapper.selectCount(qw);
		if (count > 0) {
			return BaseResponse.errorMsg("手机号已存在!");
		}

		SysUser user = new SysUser();
		BeanUtils.copyProperties(query,user);
		userMapper.insert(user);
		return BaseResponse.okData(user);
	}

	/**
	 * 修改人员
	 * @param query
	 * @return
	 */
	@Override
	@Transactional
	public BaseResponse<SysUser> update(UserQuery query) {
		if (StringUtils.isEmpty(query.getPhone())) {
			return BaseResponse.errorMsg("手机号码不可为空!");
		}
		QueryWrapper<SysUser> qw = new QueryWrapper<>();
		qw.eq("phone", query.getPhone());
		qw.ne("id", query.getId());
		int count = userMapper.selectCount(qw);
		if (count > 0) {
			return BaseResponse.errorMsg("手机号已存在!");
		}
		SysUser user = new SysUser();
		BeanUtils.copyProperties(query,user);
		user.setId(query.getId());
		userMapper.updateById(user);
		return BaseResponse.okData(user);
	}

	/**
	 * 禁用启用
	 * @param status
	 * @param id
	 * @return
	 */
	@Override
	@Transactional
	public BaseResponse<Boolean> status(Integer status, Integer id) {
		BusinessExceptionEnum.BAD_LICENCE_TYPE.assertNotNull(status);
		BusinessExceptionEnum.BAD_LICENCE_TYPE.assertNotNull(id);
		SysUser update = new SysUser();
		update.setId(id);
		update.setStatus(status == 1);
		return BaseResponse.okData(this.updateById(update));
	}

	/**
	 * 人员详情
	 * @param id
	 * @return
	 */
	@Override
	public BaseResponse<UserVo> findById(Integer id){
		BusinessExceptionEnum.BAD_LICENCE_TYPE.assertNotNull(id);
		UserVo userVo = userMapper.getById(id);
		return BaseResponse.okData(userVo);
	}
















}
